@@ -18,8 +18,12 @@
 #ifndef TERMINAL_INTL_H
 #define TERMINAL_INTL_H
 
-#include <glib/gi18n.h>
+#include <glib.h>
+
+G_BEGIN_DECLS
 
 #define I_(string) g_intern_static_string (string)
 
+G_END_DECLS
+
 #endif /* TERMINAL_INTL_H */
